//
//  SXAudioItem.h
//  SXVideoEnging
//
//  Created by Yin Xie on 2020/4/23.
//  Copyright © 2020 Zhiqiang Li. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

/**
 * 音频轨道
 * @warning 注意所有的对象对比是否相等时请使用id对比，引用可能会不同
 */
@interface SXAudioItem : NSObject
/// 音频ID
@property (nonatomic, copy, readonly) NSString *audioId;
/// 音频文件路径
@property (nonatomic, copy, readonly) NSString *filePath;
/// 音频素材原始时长
@property (nonatomic, assign, readonly) float resourceDuration;

/**
 * start time    in point                 out point    end time
 *    |             |                                  |               |
 *              Display part
 *    |             |-----------------------------|              |
 *                  |
 *                duration
 *    |-----------|-----------------------------|------------|
 *                  |
 *                 track
 * --------------------------------------------------------------------
 * 音频轨道起始时间
*/
@property (nonatomic, assign) float startTime;

///音频轨道的插入时间
@property (nonatomic, assign) float inPoint;
///音频轨道的时长
@property (nonatomic, assign) float duration;
///音量
@property (nonatomic, assign) float gain;
/// 淡入时长
@property (nonatomic, assign) float fadeIn;
///淡出时长
@property (nonatomic, assign) float fadeOut;
///变速的系数
@property (nonatomic, assign) float speed;
///变调的系数
@property (nonatomic, assign) float pitch;
///是否循环
@property (nonatomic, assign) BOOL loop;

@end

NS_ASSUME_NONNULL_END
